"""Utility functions

"""

def gbgrep2(fin, s, skipline=0, comment=''):
    """Find the next line containing a string in a file.

    fin: file handle in read mode
    s: string to find
    skipline: number of lines to further skip after s is found
    comment: lines starting with character/string 'comment' will be ignored when searching
    return: the next line containing the string; if not found, return an empty string
    result: the position pointer of fin is at the END of the next line containing s
    """
    while True:
        line = fin.readline()
        if not line: # EOF
            return ''
        if line.find(s) != -1:
            if (comment != '' and
                line.startswith(comment)):
                continue
            nextlines(fin, skipline)
            return line

def nextlines(fin, i):
    """Move the position pointer of file fin (in read mode) down i lines
    """

    for j in xrange(i):
        fin.readline()

def skipcomment(f, char='#'):
    """Skip comment lines and empty lines when reading a file
    and return the first non-comment, non-empty line.

    f: file handle
    char: character denoting a comment line, e.g. '#'
    """
    while True:
        line = f.readline()
        linesplit = line.split()
        # EOF
        if not line:
            break
        # comment or empty line
        elif line.startswith(char) or not linesplit:
            continue
        else:
            break
    return line
