from fcband.asymmband import AsymmBand
from fcband.gaussspectrum import GaussSpectrum
import copy

#-- initialize a 'base band' from universal inputs
band0 = AsymmBand.from_input('example_FeCO5.in')
#-- spectrum object that will contain all bands
spectrum = GaussSpectrum()
#-- excited states to be simulated
states = [2, 3, 6, 8, 9, 16, 17, 19, 20, 23, 24, 25, 29, 30, 33, 39, 40, 45, 46, 47]

for i in states:
    bandtmp = copy.deepcopy(band0)
    #-- read in state-specific inputs
    fin = 'force_'+str(i)+'.txt'
    bandtmp.readstuff(fin, '$forcees')
    bandtmp.readstuff(fin, '$evert')
    bandtmp.readstuff(fin, '$oscstr')
    #-- compute band parameters
    bandtmp.xe_q0()
    bandtmp.calc_band_param()
    spectrum.add_band(bandtmp)

spectrum.read_exp_spectrum('exp_spectrum.txt', energy_unit='nm',
                           normalize_to='unit_area')
#-- simulate spectrum using x values (energy points) from exp spectrum
spectrum.gen_spectrum(use_exp_xs=True, norm='oscstr')
#-- scale simulated to exp to minimize mean squared difference
MSD = spectrum.scale_sim_to_exp()
band0.printstuff('header')
print 'Simulated spectrum:'
spectrum.print_spectrum('sim', energy_unit='eV')
print '\nScaled simulated spectrum:'
spectrum.print_spectrum('scaled_sim', energy_unit='eV')
print '\nExperimental spectrum:'
spectrum.print_spectrum('exp', energy_unit='eV')
print 'Mean squared difference of scaled simulated and experimental = %.6f'%MSD

